==> db4o-5.0-mono.tar.gz: db4o-5.0/src/test/src/com/db4o/test/CaseInsensitive.cs <==
/* Copyright (C) 2004 - 2005  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;

using com.db4o.query;

namespace com.db4o.test {

    /**
     * demonstrates a case-insensitive query using an Evaluation
     */
    public class CaseInsensitive {
    
        public String name;
    
        public CaseInsensitive() {
        }
    
        public CaseInsensitive(String name) {
            this.name = name;
        }
    
        public void store(){
            Tester.store(new CaseInsensitive("HelloWorld"));
        }
    
        public void test(){
            Tester.ensure(queryingCaseInsensitiveResults("heLLOworld") == 1);
        }
    
        private int queryingCaseInsensitiveResults(string name){
            ObjectContainer objectContainer = Tester.objectContainer();
            Query q = objectContainer.query();
            q.constrain(typeof(CaseInsensitive));
            q.constrain(new CaseInsensitiveEvaluation(name));
            return q.execute().size();
        }
    }


    public class CaseInsensitiveEvaluation: Evaluation {

        String name;

        public CaseInsensitiveEvaluation(String name){
            this.name = name;
        }

        public void evaluate(Candidate candidate) {
            CaseInsensitive ci = (CaseInsensitive)candidate.getObject();
            candidate.include(ci.name.ToLower().Equals(name.ToLower()));
        }
    }
}

==> db4o-5.5-mono.tar.gz: db4o-5.5/src/test/src/com/db4o/test/CaseInsensitive.cs <==
/* Copyright (C) 2004 - 2006  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;

using com.db4o.query;

namespace com.db4o.test {

    /**
     * demonstrates a case-insensitive query using an Evaluation
     */
    public class CaseInsensitive {
    
        public String name;
    
        public CaseInsensitive() {
        }
    
        public CaseInsensitive(String name) {
            this.name = name;
        }
    
        public void Store(){
            Tester.Store(new CaseInsensitive("HelloWorld"));
        }
    
        public void Test(){
            Tester.Ensure(QueryingCaseInsensitiveResults("heLLOworld") == 1);
        }
    
        private int QueryingCaseInsensitiveResults(string name){
            ObjectContainer objectContainer = Tester.ObjectContainer();
            Query q = objectContainer.Query();
            q.Constrain(typeof(CaseInsensitive));
            q.Constrain(new CaseInsensitiveEvaluation(name));
            return q.Execute().Size();
        }
    }


    public class CaseInsensitiveEvaluation: Evaluation {

        String name;

        public CaseInsensitiveEvaluation(String name){
            this.name = name;
        }

        public void Evaluate(Candidate candidate) {
            CaseInsensitive ci = (CaseInsensitive)candidate.GetObject();
            candidate.Include(ci.name.ToLower().Equals(name.ToLower()));
        }
    }
}
